@@ -2,6 +2,7 @@ import argparse
 import gettext
 import logging
 import os
+import re
 import site
 import subprocess
 import sys
@@ -11,7 +12,7 @@ from typing import List, Union
 from urllib.request import urlopen
 
 logger = logging.getLogger(__file__)
-logger.setLevel(logging.INFO)
+logger.setLevel(logging.DEBUG)
 logger.addHandler(logging.StreamHandler())
 
 sickchill_module = Path(__file__).parent.resolve()
@@ -28,8 +29,7 @@ def locale_dir():
     return os.path.abspath(os.path.join(os.path.dirname(__file__), "locale"))
 
 
-BASE_PREFIX = getattr(sys, "base_prefix", getattr(sys, "real_prefix", sys.prefix))
-IS_VIRTUALENV = BASE_PREFIX != sys.prefix
+IS_VIRTUALENV = hasattr(sys, "real_prefix") or (hasattr(sys, "base_prefix") and sys.base_prefix != sys.prefix)
 
 
 def setup_gettext(language: str = None) -> None:
@@ -69,8 +69,6 @@ def maybe_daemonize():
         if not os.access(pid_dir, os.W_OK):
             raise SystemExit(f"PID dir: {pid_dir} must be writable (write permissions). Exiting.")
 
-    # An object is accessed for a non-existent member.
-    # Access to a protected member of a client class
     # Make a non-session-leader child process
     try:
         pid = os.fork()  # @UndefinedVariable - only available in UNIX
@@ -102,8 +100,7 @@ def maybe_daemonize():
 
         logger.info(f"Writing PID: {pid} to {pid_file}\n")
         try:
-            with open(pid_file, "w") as pid_fd:
-                pid_fd.write(f"{pid}\n")
+            pid_file.write_text(f"{pid}\n")
         except EnvironmentError as error:
             raise SystemExit(f"Unable to write PID file: {pid_file} Error {error.errno}: {error.strerror}")
 
@@ -146,21 +143,23 @@ def check_installed(name: str = __package__) -> bool:
             if result != 0:  # Not Ok
                 return False
             is_installed = name in [requirement.split("==")[0] for requirement in output.splitlines()]
-            logger.debug(f"{name} found: {is_installed}")
+            if name != "sickchill" or (name == "sickchill" and is_installed):
+                logger.debug(f"{name} installed: {is_installed}")
             return is_installed
 
     try:
         Distribution.from_name(name)
-        logger.info(f"{name} found: True")
+        logger.debug(f"{name} installed: True")
     except PackageNotFoundError:
-        logger.info(f"{name} found: False")
+        if name != "sickchill":
+            logger.debug(f"{name} installed: False")
         return False
     return True
 
 
 def subprocess_call(cmd_list):
     try:
-        process = subprocess.Popen(cmd_list, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, universal_newlines=True)
+        process = subprocess.Popen(cmd_list, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, universal_newlines=True, cwd=os.getcwd())
         stdout, stderr = process.communicate()
         process.wait()
         if stdout or stderr:
@@ -171,9 +170,24 @@ def subprocess_call(cmd_list):
     return process.returncode
 
 
+def get_os_id():
+    os_release = Path("/etc/os-release").resolve()
+    if os_release.is_file():
+        from configparser import ConfigParser
+
+        parser = ConfigParser()
+        parser.read_string("[DEFAULT]\n" + os_release.read_text())
+        try:
+            return parser["DEFAULT"]["ID"]
+        except (KeyError, IndexError):
+            pass
+
+
 def pip_install(packages: Union[List[str], str]) -> bool:
     if not isinstance(packages, list):
-        packages = packages.splitlines()
+        # clean out Warning line in list (dirty clean)
+        packages = re.sub(r"Warning.*", "", packages)
+        packages = packages.strip().splitlines()
 
     cmd = [
         sys.executable,
@@ -184,12 +198,27 @@ def pip_install(packages: Union[List[str], str]) -> bool:
         "--disable-pip-version-check",
         "--no-python-version-warning",
         "--no-color",
-        "--trusted-host=pypi.org",
-        "--trusted-host=files.pythonhosted.org",
-        "--find-links=https://wheel-index.linuxserver.io/alpine/",
-        "--find-links=https://wheel-index.linuxserver.io/ubuntu/",
+        # "--trusted-host=pypi.org",
+        # "--trusted-host=files.pythonhosted.org",
         "-qU",
-    ] + packages
+    ]
+
+    os_id = get_os_id()
+    if os_id in ("alpine", "ubuntu"):
+        cmd.append(f"--find-links=https://wheel-index.linuxserver.io/{os_id}/")
+
+    if os_id == "alpine":
+        cmd.append(f"--extra-index-url=https://alpine-wheels.github.io/index")
+
+    elif os_id in ("raspian", "osmc"):
+        cmd.append(f"--extra-index-url=https://www.piwheels.org/simple")
+
+    syno_wheelhouse = pyproject_path.parent.with_name("wheelhouse")
+    if syno_wheelhouse.is_dir():
+        logger.debug(f"Found wheelhouse dir at {syno_wheelhouse}")
+        cmd.append(f"-f{syno_wheelhouse}")
+
+    cmd += packages
 
     logger.debug(f"pip args: {' '.join(cmd)}")
 
@@ -206,10 +235,37 @@ def check_env_writable():
     """
     Checks if we can install packages to the current environment
     """
-    locations = [site.getsitepackages()[0]]
-    if site.ENABLE_USER_SITE:
-        locations.append(site.getusersitepackages())
-    return any([os.access(location, os.W_OK) for location in locations])
+    locations = []
+    try:
+        locations.append(site.getsitepackages()[0])
+    except (AttributeError, IndexError):
+        try:
+            from distutils.sysconfig import get_python_lib
+
+            locations.append(get_python_lib())
+        except (ImportError, ModuleNotFoundError):
+            pass
+
+        try:
+            import pip
+
+            locations.append(str(Path(pip.__path__[0]).parent.resolve()))
+        except (ImportError, AttributeError, IndexError):
+            pass
+
+    try:
+        if site.ENABLE_USER_SITE or site.check_enableusersite():
+            if site.USER_SITE:
+                locations.append(site.USER_SITE)
+            else:
+                locations.append(site.getusersitepackages())
+    except AttributeError:
+        pass
+
+    for location in set(locations):
+        logger.debug(f"Can write to {location}: {os.access(location, os.W_OK)}")
+
+    return any([os.access(location, os.W_OK) for location in set(locations)])
 
 
 def download_to_temp_file(url: str) -> tempfile.NamedTemporaryFile:
@@ -228,13 +284,19 @@ def check_and_install_pip() -> None:
 
     if not check_installed("pip"):
         logger.info("Installing pip")
-        tfd = download_to_temp_file("https://bootstrap.pypa.io/get-pip.py", suffix=".py", prefix="get-pip")
+        tfd = download_to_temp_file("https://bootstrap.pypa.io/get-pip.py")
         result = subprocess_call([f"{sys.executable}", f"{tfd.name}"])
-        os.unlink(tfd.name)
         if result == 0:
             logger.info("Pip installed")
         else:
-            logger.info("There was an error installing pip!")
+            logger.info("There was an error installing pip! Trying user site")
+            result = subprocess_call([f"{sys.executable}", f"{tfd.name}", "--user"])
+            if result == 0:
+                logger.info("Pip installed")
+            else:
+                logger.info("There was an error installing pip!")
+
+        os.unlink(tfd.name)
 
 
 def make_virtualenv_and_rerun(location: Path) -> None:
@@ -258,21 +320,27 @@ def make_virtualenv_and_rerun(location: Path) -> None:
     else:
         if not location.is_dir():
             logger.info(f"Because of the above errors, we will try creating a new virtualenvironment in {location}")
-            if not check_installed("virtualenv"):
-                logger.info("virtualenv module not found, getting a portable one to use temporarily")
-                tfd = download_to_temp_file("https://bootstrap.pypa.io/virtualenv.pyz", suffix=".pyz", prefix="virtualenv")
-                result = subprocess_call([f"{sys.executable}", f"{tfd.name}", "-p", f"{sys.executable}", f"{location}"])
-                os.unlink(tfd.name)
-                if result != 0:  # Not Ok
-                    logger.info("Due to the above error, we cannot continue! Exiting")
+            try:
+                import venv
+
+                venv.create(location, system_site_packages=False, clear=True, symlinks=os.name != "nt", with_pip=True)
+                logger.info(f"Created new virtualenvironment in {location} using venv module!")
+            except:
+                if check_installed("virtualenv"):
+                    result = subprocess_call([f"{sys.executable}", "-m", "virtualenv", "-p", f"{sys.executable}", f"{location}"])
+                    if result != 0:  # Not Ok
+                        logger.info("Due to the above error, we cannot continue! Exiting")
+                    else:
+                        logger.info(f"Created new virtualenvironment in {location}")
                 else:
-                    logger.info(f"Created new virtualenvironment in {location}")
-            else:
-                result = subprocess_call([f"{sys.executable}", "-m", "virtualenv", "-p", f"{sys.executable}", f"{location}"])
-                if result != 0:  # Not Ok
-                    logger.info("Due to the above error, we cannot continue! Exiting")
-                else:
-                    logger.info(f"Created new virtualenvironment in {location}")
+                    logger.info("virtualenv module not found, getting a portable one to use temporarily")
+                    tfd = download_to_temp_file("https://bootstrap.pypa.io/virtualenv.pyz")
+                    result = subprocess_call([f"{sys.executable}", f"{tfd.name}", "-p", f"{sys.executable}", f"{location}"])
+                    os.unlink(tfd.name)
+                    if result != 0:  # Not Ok
+                        logger.info("Due to the above error, we cannot continue! Exiting")
+                    else:
+                        logger.info(f"Created new virtualenvironment in {location}")
 
         if location.is_dir() and result == 0:  # Ok
             locations_to_check = []
@@ -325,7 +393,7 @@ def poetry_install() -> None:
             check_and_install_pip()
 
             # Cool, we can write to site-packages
-            pip_install(["setuptools", "poetry", "--pre"])
+            pip_install(["setuptools", "poetry", "wheel"])
             if check_installed("poetry"):
                 result, output = subprocess.getstatusoutput(
                     f"cd {pyproject_path.parent} && {sys.executable} -m poetry export -f requirements.txt --without-hashes"
