@@ -87,7 +87,7 @@ copyfileobj_orig = shutil.copyfileobj
 
 
 def _copyfileobj(fsrc, fdst, length=10485760):
-    """ Run shutil.copyfileobj with a bigger buffer """
+    """Run shutil.copyfileobj with a bigger buffer"""
     return copyfileobj_orig(fsrc, fdst, length)
 
 
@@ -704,7 +704,7 @@ def sanitizeSceneName(name, anime=False):
 
     # tidy up stuff that doesn't belong in scene names
     name = name.replace("&", "and")
-    name = re.sub(r"[-/\s]+", ".", name)
+    name = re.sub(r"[-/…\s]+", ".", name)
     name = re.sub(r"[.]+", ".", name)
 
     if name.endswith("."):
@@ -722,15 +722,11 @@ def create_https_certificates(ssl_cert, ssl_key):
     :return: True on success, False on failure
     """
 
-    # assert isinstance(ssl_key, unicode)
-    # assert isinstance(ssl_cert, unicode)
-
-    # noinspection PyBroadException
     try:
         from OpenSSL import crypto
 
         from sickchill.certgen import createCertificate, createCertRequest, createKeyPair, TYPE_RSA
-    except Exception:
+    except (ImportError, ModuleNotFoundError):
         logger.info(traceback.format_exc())
         logger.warning(_("pyopenssl module missing, please install for https access"))
         return False
@@ -1356,7 +1352,7 @@ def handle_requests_exception(requests_exception):
     except (TypeError, ValueError) as error:
         level = get_level(error)
         logger.log(level, default.format(error, type(error.__class__.__name__)))
-        if requests_exception.request:
+        if hasattr(requests_exception, "request") and requests_exception.request:
             logger.info(_("url is {0}").format(repr(requests_exception.request.url)))
             logger.info("headers are {0}".format(repr(requests_exception.request.headers)))
             logger.info("params are {0}".format(repr(requests_exception.request.params)))
@@ -1396,7 +1392,7 @@ def get_size(start_path="."):
 
 
 def generateApiKey():
-    """ Return a new randomized API_KEY"""
+    """Return a new randomized API_KEY"""
     logger.info(_("Generating New API key"))
     secure_hash = hashlib.sha512(str(time.time()).encode())
     secure_hash.update(str(random.SystemRandom().getrandbits(4096)).encode())
