@@ -52,7 +52,6 @@ class ConfigPostProcessing(Config):
         unpack_dir=None,
         unrar_tool=None,
         unar_tool=None,
-        bsdtar_tool=None,
         move_associated_files=None,
         delete_non_associated_files=None,
         sync_files=None,
@@ -87,7 +86,7 @@ class ConfigPostProcessing(Config):
         config.change_process_automatically(process_automatically)
         settings.USE_ICACLS = config.checkbox_to_value(use_icacls)
 
-        config.change_unrar_tool(unrar_tool, unar_tool, bsdtar_tool)
+        config.change_unrar_tool(unrar_tool, unar_tool)
 
         unpack = try_int(unpack)
         if unpack == settings.UNPACK_PROCESS_CONTENTS:
@@ -214,7 +213,7 @@ class ConfigPostProcessing(Config):
         """
         Test Unpacking Support: - checks if unrar is installed and accesible
         """
-        check = config.change_unrar_tool(settings.UNRAR_TOOL, settings.UNAR_TOOL, settings.BSDTAR_TOOL)
+        check = config.change_unrar_tool(settings.UNRAR_TOOL, settings.UNAR_TOOL)
         if not check:
             logger.warning("Looks like unrar is not installed, check failed")
         return ("not supported", "supported")[check]
